class FileMetadata:
    def __init__(
            self,
            file_type: str,
            file_id: str,
            file_name: str
    ):
        self.file_type = file_type
        self.file_id = file_id
        self.filename = file_name
