DEFAULT_USER = "USER"
TYPE = "type"
ID = "id"
UI_STATE = "uiState"
RECIPIENT = "recipient"
CONTENT = "content"
COMMANDS = "commands"
CAPTION = "caption"
METADATA = "metadata"
ACTION = "action"
FILE_ID = "fileId"
NAME = "name"
FILE_TYPE = "mediaType"
SEND_MESSAGE = "SendMessage"
FORWARD_MESSAGE = "ForwardMessage"
EDIT_MESSAGE = "EditMessage"
SEND_UI_STATE = "SendUiState"
SEND_CONTAINER_MESSAGE = "SendContainerMessage"
SEND_CONTACT_MESSAGE = "SendContactMessage"
MEDIA_LIST = "mediaList"
LOCAL_ID = "localId"
GET_UPDATES = "GetUpdates"
UPLOADED_FILES = "uploadedFiles"
QUICK_BUTTON_COMMANDS = "quickButtonCommands"
FORM_MESSAGE = "formMessage"
INLINE_COMMANDS = "inlineCommands"
REPLY_KEYBOARD = "replyKeyboard"
SHOW_CAMERA_BUTTON = "showCameraButton"
SHOW_SHARE_CONTACT_BUTTON = "showShareContactButton"
SHOW_RECORD_AUDIO_BUTTON = "showRecordAudioButton"
SHOW_GALLERY_BUTTON = "showGalleryButton"
INPUT_MEDIA = "inputMedia"
MESSAGE_ID = "messageId"
FROM_DIALOG = "fromDialog"
TO_DIALOG = "toDialog"
