class Indent:
    def __init__(self, left: int = None, top: int = None, right: int = None, bottom: int = None):
        self.left = left
        self.top = top
        self.right = right
        self.bottom = bottom
